@@ -24,21 +24,13 @@ from base.indiClass import IndiClass
 
 class CoverIndi(IndiClass):
     """
-    the class FlipFlatIndi inherits all information and handling of the FlipFlat device
-
-        >>> f = CoverIndi(app=None)
     """
 
-    __all__ = ['CoverIndi',
-               ]
-
-    # update rate to 1 seconds for setting indi server
-    UPDATE_RATE = 1
+    __all__ = ['CoverIndi']
 
     def __init__(self, app=None, signals=None, data=None):
-        super().__init__(app=app, threadPool=app.threadPool)
-
         self.signals = signals
+        super().__init__(app=app, threadPool=app.threadPool)
         self.data = data
 
     def setUpdateConfig(self, deviceName):
