@@ -24,8 +24,7 @@ from base.ascomClass import AscomClass
 
 class SensorWeatherAscom(AscomClass):
 
-    __all__ = ['SensorWeatherAscom',
-               ]
+    __all__ = ['SensorWeatherAscom']
 
     def __init__(self, app=None, signals=None, data=None):
         super().__init__(app=app, data=data, threadPool=app.threadPool)
@@ -33,13 +32,6 @@ class SensorWeatherAscom(AscomClass):
         self.signals = signals
         self.data = data
 
-    def workerGetInitialConfig(self):
-        """
-        :return: true for test purpose
-        """
-        super().workerGetInitialConfig()
-        return True
-
     def workerPollData(self):
         """
         :return: true for test purpose
