@@ -24,7 +24,8 @@ from queue import Queue
 import platform
 
 # external packages
-if platform.system() == 'Windows' and platform.python_version() >= '3.8.2':
+from base.packageConfig import checkAutomation
+if checkAutomation():
     from logic.automation.automateWindows import AutomateWindows
 
 from PyQt5.QtCore import QObject, pyqtSignal, QThreadPool, QTimer
@@ -195,7 +196,7 @@ class MountWizzard4(QObject):
 
         :return:
         """
-        if platform.system() != 'Windows' or platform.python_version() < '3.8.2':
+        if not checkAutomation():
             return None
 
         automation = AutomateWindows(self)
